==> vue-sb-components-2.1.5.tgz: package/components/form-input/form-input.js <==
import "./form-input.css";
import { defineComponent as k, openBlock as o, createElementBlock as s, mergeProps as d, createElementVNode as a, normalizeClass as t, toDisplayString as h, createCommentVNode as i, renderSlot as g, Fragment as p, withDirectives as b, vModelDynamic as I, vModelText as M, createTextVNode as V } from "vue";
import { _ as q } from "../../_plugin-vue_export-helper-dad06003.js";
const c = k({
  emits: {
    "update:modelValue": (e) => !0,
    blur: (e) => !0,
    focus: (e) => !0,
    input: (e) => !0,
    keydown: (e) => !0
  },
  props: {
    autocomplete: {
      default: "on",
      type: String
    },
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    icon: {
      required: !1,
      type: Object
    },
    isError: {
      required: !1,
      type: Boolean
    },
    isFocus: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    max: {
      required: !1,
      type: [Number, String]
    },
    min: {
      required: !1,
      type: [Number, String]
    },
    modelValue: {
      required: !1,
      type: null
    },
    noSavePassword: {
      required: !1,
      type: Boolean
    },
    placeholder: {
      required: !1,
      type: String
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    step: {
      required: !1,
      type: Number
    },
    tabindex: {
      required: !1,
      type: Number
    },
    textAlign: {
      default: "left",
      type: String
    },
    type: {
      default: "text",
      type: String
    },
    value: {
      required: !1,
      type: null
    },
    variant: {
      default: "default",
      required: !1,
      type: String
    }
  },
  name: "sb-form-input",
  data() {
    return {
      localIsFocus: !1,
      localValue: this.modelValue || this.value || null
    };
  },
  computed: {
    getInputType() {
      return this.type === "password" && this.noSavePassword ? "text" : this.type;
    },
    isFilled() {
      var e;
      return this.localValue !== null && typeof this.localValue < "u" ? this.type !== "number" ? this.localValue !== "" && (((e = this.localValue) == null ? void 0 : e.length) || Object.keys(this.localValue).length > 0) : !0 : !1;
    }
  },
  methods: {
    handleBlur(e) {
      this.localIsFocus = !1, this.$emit("blur", e);
    },
    handleChange(e) {
      this.$emit("input", e), this.$emit("update:modelValue", this.localValue);
    },
    handleClickIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onClick) && this.icon.onClick(e);
    },
    handleClickOutsideInput(e) {
      const l = e.target, r = this.$refs["input-wrapper"];
      l && r && !r.contains(l) && !l.isSameNode(r) && this.toggleFocus(!1);
    },
    handleErrorMessage() {
      return this.errorMessage ? typeof this.errorMessage == "string" ? this.errorMessage : this.errorMessage(this.localValue) : "";
    },
    handleInputFocus(e) {
      this.localIsFocus = !0, this.$emit("focus", e);
    },
    handleMouseLeaveIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseLeave) && this.icon.onMouseLeave(e);
    },
    handleMouseOverIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseOver) && this.icon.onMouseOver(e);
    },
    toggleFocus(e, l) {
      if (l) {
        const r = l.target, u = r == null ? void 0 : r.querySelectorAll("input, textarea");
        u.length > 0 && u[0].focus();
      }
      this.localIsFocus = e;
    }
  },
  watch: {
    isFocus(e) {
      this.localIsFocus = e;
    },
    modelValue: {
      deep: !0,
      handler(e) {
        this.localValue = e;
      }
    },
    value: {
      deep: !0,
      handler(e) {
        this.localValue = e;
      }
    }
  },
  mounted() {
    document.addEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  },
  unmounted() {
    document.removeEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  }
});
const F = {
  key: 0,
  class: "asterisk"
}, w = ["type", "tabindex"], C = ["tabindex"], O = { class: "input-border" }, S = { class: "notch" }, $ = {
  key: 0,
  class: "asterisk"
}, B = {
  key: 0,
  class: "error-wrapper"
}, E = ["innerHTML"];
function L(e, l, r, u, v, N) {
  var y, m, f;
  return o(), s("div", d({
    class: ["input-wrapper", { error: e.isError, flat: e.variant === "flat" }],
    ref: "input-wrapper"
  }, { ...e.$attrs }), [
    a("div", {
      class: t(["input-group", {
        disabled: e.disabled,
        filled: e.isFilled,
        focus: e.isFocus || e.localIsFocus,
        icon_append: ((y = e.icon) == null ? void 0 : y.placement) === "append",
        icon_prepend: ((m = e.icon) == null ? void 0 : m.placement) === "prepend",
        "multi-line": e.type === "textarea",
        readonly: e.readOnly
      }])
    }, [
      e.label ? (o(), s("label", {
        key: 0,
        class: t(["label", { required: e.required, multiline: e.type === "textarea" }])
      }, [
        a("span", null, h(e.label), 1),
        e.required ? (o(), s("span", F, "*")) : i("", !0)
      ], 2)) : i("", !0),
      e.icon ? (o(), s("span", {
        key: 1,
        class: t([{
          "sb-cursor-pointer": (f = e.icon) == null ? void 0 : f.onClick
        }, "icon"]),
        onClick: l[0] || (l[0] = (...n) => e.handleClickIcon && e.handleClickIcon(...n)),
        onMouseover: l[1] || (l[1] = (...n) => e.handleMouseOverIcon && e.handleMouseOverIcon(...n)),
        onMouseleave: l[2] || (l[2] = (...n) => e.handleMouseLeaveIcon && e.handleMouseLeaveIcon(...n))
      }, [
        g(e.$slots, "icon-slot")
      ], 34)) : i("", !0),
      a("div", {
        class: t(["form-control", [e.textAlign, e.type, e.noSavePassword && "no-save-password"]]),
        onClick: l[13] || (l[13] = (n) => e.toggleFocus(!0, n))
      }, [
        e.$slots["custom-input"] ? g(e.$slots, "custom-input", { key: 1 }) : (o(), s(p, { key: 0 }, [
          e.type !== "textarea" ? b((o(), s("input", d({
            key: 0,
            type: e.getInputType,
            tabindex: e.readOnly || e.disabled ? -1 : e.tabindex,
            "onUpdate:modelValue": l[3] || (l[3] = (n) => e.localValue = n)
          }, {
            autocomplete: e.autocomplete,
            disabled: e.disabled,
            min: e.min,
            max: e.max,
            placeholder: e.placeholder,
            step: e.step,
            readonly: e.readOnly
          }, {
            onBlur: l[4] || (l[4] = (n) => e.handleBlur(n)),
            onFocus: l[5] || (l[5] = (n) => e.handleInputFocus(n)),
            onInput: l[6] || (l[6] = (n) => e.handleChange(n)),
            onKeydown: l[7] || (l[7] = (n) => e.$emit("keydown", n))
          }), null, 16, w)), [
            [I, e.localValue]
          ]) : b((o(), s("textarea", d({
            key: 1,
            class: { readonly: e.readOnly },
            rows: "6",
            tabindex: e.readOnly || e.disabled ? -1 : e.tabindex
          }, {
            autocomplete: e.autocomplete,
            disabled: e.disabled,
            placeholder: e.placeholder,
            readonly: e.readOnly
          }, {
            "onUpdate:modelValue": l[8] || (l[8] = (n) => e.localValue = n),
            onBlur: l[9] || (l[9] = (n) => e.handleBlur(n)),
            onFocus: l[10] || (l[10] = (n) => e.handleInputFocus(n)),
            onInput: l[11] || (l[11] = (n) => e.handleChange(n)),
            onKeydown: l[12] || (l[12] = (n) => e.$emit("keydown", n))
          }), null, 16, C)), [
            [M, e.localValue]
          ])
        ], 64))
      ], 2),
      a("fieldset", O, [
        a("legend", S, [
          a("span", {
            class: t(["notch-label", { "no-label": !e.label || e.label === "" }])
          }, [
            e.label && e.label !== "" ? (o(), s(p, { key: 0 }, [
              a("span", null, h(e.label), 1),
              e.required ? (o(), s("span", $, "*")) : i("", !0)
            ], 64)) : (o(), s(p, { key: 1 }, [
              V("​")
            ], 64))
          ], 2)
        ])
      ])
    ], 2),
    e.isError && e.errorMessage ? (o(), s("div", B, [
      a("span", {
        innerHTML: e.handleErrorMessage()
      }, null, 8, E)
    ])) : i("", !0)
  ], 16);
}
const A = /* @__PURE__ */ q(c, [["render", L]]);
export {
  A as default
};

==> vue-sb-components-2.3.32.tgz: package/components/form-input/form-input.js <==
import "./form-input.css";
import { defineComponent as k, openBlock as o, createElementBlock as s, mergeProps as d, createElementVNode as a, normalizeClass as t, toDisplayString as h, createCommentVNode as i, renderSlot as g, Fragment as p, withDirectives as b, vModelDynamic as I, vModelText as q, createTextVNode as M } from "vue";
import { _ as V } from "../../_plugin-vue_export-helper-dad06003.js";
const F = k({
  emits: {
    "update:modelValue": (e) => !0,
    blur: (e) => !0,
    focus: (e) => !0,
    input: (e) => !0,
    keydown: (e) => !0
  },
  props: {
    autocomplete: {
      default: "on",
      type: String
    },
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    icon: {
      required: !1,
      type: Object
    },
    isError: {
      required: !1,
      type: Boolean
    },
    isFocus: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    max: {
      required: !1,
      type: [Number, String]
    },
    min: {
      required: !1,
      type: [Number, String]
    },
    modelValue: {
      required: !1,
      type: null
    },
    name: {
      required: !1,
      type: String
    },
    noSavePassword: {
      required: !1,
      type: Boolean
    },
    placeholder: {
      required: !1,
      type: String
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    step: {
      required: !1,
      type: Number
    },
    tabindex: {
      required: !1,
      type: Number
    },
    textAlign: {
      default: "left",
      type: String
    },
    type: {
      default: "text",
      type: String
    },
    value: {
      required: !1,
      type: null
    },
    variant: {
      default: "default",
      required: !1,
      type: String
    }
  },
  name: "sb-form-input",
  data() {
    return {
      localIsFocus: !1,
      localValue: this.modelValue || this.value || null
    };
  },
  computed: {
    getInputType() {
      return this.type === "password" && this.noSavePassword ? "text" : this.type;
    },
    isFilled() {
      var e;
      return this.localValue !== null && typeof this.localValue < "u" ? this.type !== "number" ? this.localValue !== "" && (((e = this.localValue) == null ? void 0 : e.length) || Object.keys(this.localValue).length > 0) : !0 : !1;
    }
  },
  methods: {
    handleBlur(e) {
      this.localIsFocus = !1, this.$emit("blur", e);
    },
    handleChange(e) {
      this.$emit("input", e), this.$emit("update:modelValue", this.localValue);
    },
    handleClickIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onClick) && this.icon.onClick(e);
    },
    handleClickOutsideInput(e) {
      const l = e.target, r = this.$refs["input-wrapper"];
      l && r && !r.contains(l) && !l.isSameNode(r) && this.toggleFocus(!1);
    },
    handleErrorMessage() {
      return this.errorMessage ? typeof this.errorMessage == "string" ? this.errorMessage : this.errorMessage(this.localValue) : "";
    },
    handleInputFocus(e) {
      this.localIsFocus = !0, this.$emit("focus", e);
    },
    handleMouseLeaveIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseLeave) && this.icon.onMouseLeave(e);
    },
    handleMouseOverIcon(e) {
      var l;
      return ((l = this.icon) == null ? void 0 : l.onMouseOver) && this.icon.onMouseOver(e);
    },
    toggleFocus(e, l) {
      if (l) {
        const r = l.target, u = r == null ? void 0 : r.querySelectorAll("input, textarea");
        u.length > 0 && u[0].focus();
      }
      this.localIsFocus = e;
    }
  },
  watch: {
    isFocus(e) {
      this.localIsFocus = e;
    },
    modelValue: {
      deep: !0,
      handler(e) {
        this.localValue = e;
      }
    },
    value: {
      deep: !0,
      handler(e) {
        this.localValue = e;
      }
    }
  },
  mounted() {
    document.addEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  },
  unmounted() {
    document.removeEventListener(
      "click",
      (e) => this.handleClickOutsideInput(e)
    );
  }
});
const c = {
  key: 0,
  class: "asterisk"
}, w = ["name", "type", "tabindex"], C = ["name", "tabindex"], O = { class: "input-border" }, S = { class: "notch" }, $ = {
  key: 0,
  class: "asterisk"
}, B = {
  key: 0,
  class: "error-wrapper"
}, E = ["innerHTML"];
function L(e, l, r, u, v, N) {
  var m, y, f;
  return o(), s("div", d({
    class: ["input-wrapper", { error: e.isError, flat: e.variant === "flat" }],
    ref: "input-wrapper"
  }, { ...e.$attrs }), [
    a("div", {
      class: t(["input-group", {
        disabled: e.disabled,
        filled: e.isFilled,
        focus: e.isFocus || e.localIsFocus,
        icon_append: ((m = e.icon) == null ? void 0 : m.placement) === "append",
        icon_prepend: ((y = e.icon) == null ? void 0 : y.placement) === "prepend",
        "multi-line": e.type === "textarea",
        readonly: e.readOnly
      }])
    }, [
      e.label ? (o(), s("label", {
        key: 0,
        class: t(["label", { required: e.required, multiline: e.type === "textarea" }])
      }, [
        a("span", null, h(e.label), 1),
        e.required ? (o(), s("span", c, "*")) : i("", !0)
      ], 2)) : i("", !0),
      e.icon ? (o(), s("span", {
        key: 1,
        class: t([{
          "sb-cursor-pointer": (f = e.icon) == null ? void 0 : f.onClick
        }, "icon"]),
        onClick: l[0] || (l[0] = (...n) => e.handleClickIcon && e.handleClickIcon(...n)),
        onMouseover: l[1] || (l[1] = (...n) => e.handleMouseOverIcon && e.handleMouseOverIcon(...n)),
        onMouseleave: l[2] || (l[2] = (...n) => e.handleMouseLeaveIcon && e.handleMouseLeaveIcon(...n))
      }, [
        g(e.$slots, "icon-slot")
      ], 34)) : i("", !0),
      a("div", {
        class: t(["form-control", [e.textAlign, e.type, e.noSavePassword && "no-save-password"]]),
        onClick: l[13] || (l[13] = (n) => e.toggleFocus(!0, n))
      }, [
        e.$slots["custom-input"] ? g(e.$slots, "custom-input", { key: 1 }) : (o(), s(p, { key: 0 }, [
          e.type !== "textarea" ? b((o(), s("input", d({
            key: 0,
            name: e.name,
            type: e.getInputType,
            tabindex: e.readOnly || e.disabled ? -1 : e.tabindex,
            "onUpdate:modelValue": l[3] || (l[3] = (n) => e.localValue = n)
          }, {
            autocomplete: e.autocomplete,
            disabled: e.disabled,
            min: e.min,
            max: e.max,
            placeholder: e.placeholder,
            step: e.step,
            readonly: e.readOnly
          }, {
            onBlur: l[4] || (l[4] = (n) => e.handleBlur(n)),
            onFocus: l[5] || (l[5] = (n) => e.handleInputFocus(n)),
            onInput: l[6] || (l[6] = (n) => e.handleChange(n)),
            onKeydown: l[7] || (l[7] = (n) => e.$emit("keydown", n))
          }), null, 16, w)), [
            [I, e.localValue]
          ]) : b((o(), s("textarea", d({
            key: 1,
            class: { readonly: e.readOnly },
            name: e.name,
            tabindex: e.readOnly || e.disabled ? -1 : e.tabindex,
            rows: "6"
          }, {
            autocomplete: e.autocomplete,
            disabled: e.disabled,
            placeholder: e.placeholder,
            readonly: e.readOnly
          }, {
            "onUpdate:modelValue": l[8] || (l[8] = (n) => e.localValue = n),
            onBlur: l[9] || (l[9] = (n) => e.handleBlur(n)),
            onFocus: l[10] || (l[10] = (n) => e.handleInputFocus(n)),
            onInput: l[11] || (l[11] = (n) => e.handleChange(n)),
            onKeydown: l[12] || (l[12] = (n) => e.$emit("keydown", n))
          }), null, 16, C)), [
            [q, e.localValue]
          ])
        ], 64))
      ], 2),
      a("fieldset", O, [
        a("legend", S, [
          a("span", {
            class: t(["notch-label", { "no-label": !e.label || e.label === "" }])
          }, [
            e.label && e.label !== "" ? (o(), s(p, { key: 0 }, [
              a("span", null, h(e.label), 1),
              e.required ? (o(), s("span", $, "*")) : i("", !0)
            ], 64)) : (o(), s(p, { key: 1 }, [
              M("​")
            ], 64))
          ], 2)
        ])
      ])
    ], 2),
    e.isError && e.errorMessage ? (o(), s("div", B, [
      a("span", {
        innerHTML: e.handleErrorMessage()
      }, null, 8, E)
    ])) : i("", !0)
  ], 16);
}
const A = /* @__PURE__ */ V(F, [["render", L]]);
export {
  A as default
};
